@@ -1,13 +1,19 @@
 #-*- coding:utf-8 -*-
 
+from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 from django.db import models
 
-from nscms.base.db.models import PublisherModel, ContentModel
+from nscms.base.content.models import PublisherModel, ContentModel
+
+
+SIMPLENEWS_IMAGE_UPLOAD_TO = \
+    getattr(settings, "SIMPLENEWS_IMAGE_UPLOAD_TO", "simplenews")
 
 
 class SimpleNewsModel(ContentModel, PublisherModel):
-    image = models.ImageField(upload_to='/simplesnews/', max_length=255)
+    image = models.ImageField(
+        upload_to=SIMPLENEWS_IMAGE_UPLOAD_TO, max_length=255)
 
     class Meta:
         ordering = ['-publish_date']
